#
# spec file for package python-injector
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-injector
Version:        0.21.0
Release:        1.5
Summary:        Python dependency injection framework, inspired by Guice
License:        BSD-3-Clause
URL:            https://github.com/alecthomas/injector
Source:         https://github.com/alecthomas/injector/archive/%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing_extensions >= 3.7.4 if %python-base < 3.9}
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module dataclasses if %python-base < 3.7}
# /SECTION
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros >= 20210131
Requires:       python
%if %{python_version_nodots} < 39
Requires:       python-typing_extensions >= 3.7.4
%endif
BuildArch:      noarch
%python_subpackages

%description
Dependency injection as a formal pattern is less useful in Python than
in other languages, primarily due to its support for keyword
arguments, the ease with which objects can be mocked, and its dynamic
nature.

That said, a framework for assisting in this process can remove a lot
of boiler-plate from larger applications. That's where Injector can
help. It automatically and transitively provides keyword arguments
with their values. As an added benefit, Injector encourages nicely
compartmentalised code through the use of Module s.

While being inspired by Guice, it does not slavishly replicate its
API. Providing a Pythonic API trumps faithfulness.

%prep
%setup -q -n injector-%{version}
rm pytest.ini

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license COPYING
%doc README.md
%{python_sitelib}/injector
%{python_sitelib}/injector-%{version}*-info

%changelog
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.21.0:
  * Improved the documentation, thanks to jonathanmach and Jakub
    Wilk
  * Fixed a thread-safety regression
  * Improved the type annotations, thanks to David Pärsson
  * Fixed singleton scope behavior with parent/child injectors,
  thanks to David Pärsson
  * Stopped using a deprecated test function, thanks to ljnsn
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.20.1
  - Added support for PEP 604 union types (Python 3.10+), thanks to David Pärsson
  - Fixed building with pypandoc 1.8+, thanks to Søren Fuglede Jørgensen
- Update to 0.20.0
  - Fixed handling of Union combined with Annotated, thanks to Tobias Nilsson
  - Fixed AssitedBuilder/child Injector interaction, thanks to Erik Cederberg
  - Made get_bindings() and injections work even if a injectee's return type
    annotation is a forward reference that can't be resolved
  Backwards incompatible:
  - Dropped Python 3.6 support
* Mon Jan 10 2022 Ben Greiner <code@bnavigator.de>
- Fix test and runtime requirements
* Fri Dec 31 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.19.0:
  - Added the license to the source distribution, thanks to
    Joshua Adelman
  - Added Python 3.9 and 3.10 support, this includes fixing
    Python 3.10 compatibility, thanks to Torge Matthies
  - Improved the documentation, thanks to Takahiro Kojima
  - Improved the source distribution so that it can be used to
    build and install wheels, thanks to Janusz Skonieczny
  - Added requirements files for easier development, thanks to
    Greg Eremeev
  - Removed Python 3.5 support
  - Fixed a bug where only one of multiple NoInject annotations
    was interpreted
* Thu Jan 28 2021 Steve Kowalik <steven.kowalik@suse.com>
- BuildRequires on the dataclasses module if using python 3.6
* Thu Apr  9 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.18.3:
  * Fixed Python 3.5.3 compatibility
  * Added remaining type hints to the codebase so that the client code can
    have better static typing safety
  * Fixed UnsatisfiedRequirement string representation (this time for real)
  * Added forward return type reference support to provider methods
* Wed Dec 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.18.1:
  * Various minor fixes and support for new python
- Depend on full python interpreter for sqlite module
* Wed Jul 24 2019 pgajdos@suse.com
- version update to 0.17.0
  * Added support for using `typing.Dict` and `typing.List` in multibindings. See :meth:`multibind <injector.Binder.multibind>`.
  * Added multibinding-specific :func:`provider <injector.provider>` variant: :func:`multiprovider <injector.multiprovider>`
  * Deprecated using :func:`provider <injector.provider>` for multibindings
  * Fixed failure to provide a default value to a `NewType`-aliased type with auto_bind enabled
  * Deprecated :func:`Key <injector.Key>`, :func:`SequenceKey <injector.SequenceKey>` and
    :func:`MappingKey <injector.MappingKey>` – use real types or type aliases instead
  * Deprecated using single-item lists and dictionaries for multibindings - use real types or type aliases instead
  Technically backwards incompatible:
  * typing.List and typing.Dict specializations are now explicitly disallowed as :meth:`bind <injector.Binder.bind>`
    interfaces and types returned by :func:`provider <injector.provider>`-decorated methods
* Tue Jun 11 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.16.2
  * Added support for overriding injectable parameters with positional
    arguments (previously only possible with keyword arguments)
  * Fixed crashes caused by typed self in method signatures
  * Dropped Python 3.4 support
  * Removed previously deprecated constructs: with_injector,
    Injector.install_into, Binder.bind_scope
  * Dependencies are no longer injected into Module.configure and
    raw module functions
  * Removed unofficial support for injecting into parent class
    constructors
* Mon Feb 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball to get both tests and license file
* Sat Feb 16 2019 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v0.15.0)
